libkrun 1.18.0

A dynamic library providing Virtualization-based process isolation capabilities
docs.rs failed to build libkrun-1.18.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.